#### General

Node ID
  {$ ctrl.node.uuid $}
Chassis ID
  {$ ctrl.node.chassis_uuid $}
Created At
  {$ ctrl.node.created_at $}
Extra
  {$ ctrl.node.extra $}

#### Ports

{$ 'MAC ' + (1 + $index) $}
  {$ port.address $}
  {$ port.address $}

#### Properties

Memory
  {$ ctrl.node.properties.memory_mb + ' MB' $}
CPU Arch
  {$ ctrl.node.properties.cpu_arch $}
Local GB
  {$ ctrl.node.properties.local_gb $}
CPUs
  {$ ctrl.node.properties.cpus $}

#### Driver Info

Driver
  {$ ctrl.node.driver $}
SSH Port
  {$ ctrl.node.driver_info.ssh_port $}
SSH Username
  {$ ctrl.node.driver_info.ssh_username $}
Deploy Kernel
  {$ ctrl.node.driver_info.deploy_kernel $} {$ ctrl.node.driver_info.deploy_kernel $}
Deploy Ramdisk
  {$ ctrl.node.driver_info.deploy_ramdisk $} {$ ctrl.node.driver_info.deploy_ramdisk $}

{$ id $}
  {$ value $}

#### Capabilities

  {$ ctrl.node.capabilities $}

#### Instance Info

Instance Name
  {$ ctrl.node.instance_info.display_name $}
Ramdisk
  {$ ctrl.node.instance_info.ramdisk $}
Kernel
  {$ ctrl.node.instance_info.kernel $}